| Type: | Package |
| Title: | Meta-Package for Compositional Data Analysis |
| Version: | 0.1.2 |
| Description: | Meta-package for compositional data analysis. It attaches the main stable packages of the 'coda' ecosystem, currently 'coda.base' and 'coda.plot', and provides helper tools to install development extensions from 'GitHub'. |
| License: | GPL (≥ 3) |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.2 |
| Depends: | R (≥ 4.1.0), coda.base, coda.plot |
| Suggests: | remotes |
| NeedsCompilation: | no |
| Packaged: | 2026-03-12 13:27:43 UTC; marc |
| Author: | Marc Comas-Cufí |
| Maintainer: | Marc Comas-Cufí <mcomas@imae.udg.edu> |
| Repository: | CRAN |
| Date/Publication: | 2026-04-10 09:40:09 UTC |
coda.pack: Meta-Package for Compositional Data Analysis
Description
coda.pack is a meta-package for compositional data analysis. It attaches
the main stable packages of the coda ecosystem.
Details
The following packages are attached by default:
-
coda.base -
coda.plot
Development extensions can be installed with install_coda_dev().
Value
No return value, called for its side effects of attaching the package and its imports.
Author(s)
Maintainer: Marc Comas-Cufí mcomas@imae.udg.edu (ORCID)
Examples
library(coda.pack)
Development repositories in the coda ecosystem
Description
Development repositories in the coda ecosystem
Usage
coda_dev_repos()
Value
A character vector. Each element is a GitHub repository identifier
of the form "owner/repository" corresponding to a development package
in the coda ecosystem.
Examples
coda_dev_repos()
List packages in the coda ecosystem
Description
Returns a data frame with the packages currently considered part of the
coda ecosystem and their installation source.
Usage
coda_packages()
Value
A data frame with one row per package and two columns:
- package
Package name.
- source
Source from which the package can be installed, currently either
"CRAN"or"GitHub".
The returned object is of class data.frame.
Examples
coda_packages()
Install development packages from the coda ecosystem
Description
Installs the development extensions of the coda ecosystem from GitHub.
Usage
install_coda_dev(upgrade = "never")
Arguments
upgrade |
Upgrade policy passed to |
Details
Currently, this function installs:
-
coda.count -
coda.stats -
coda.dist
Value
Invisibly returns a character vector with the GitHub repositories
that were passed to remotes::install_github(). Each element is of the
form "owner/repository".